package org.szte.code.client;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JFormattedTextField;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.UIManager;

/**
 *  2013, SZTE, CIRENE project, GPL licence http://www.gnu.org/licenses/gpl-2.0.html
 *  
 *  @author Rcz, Rbert
 *
 */


public class Window extends JFrame {

	private static final long serialVersionUID = 5919865068932109661L;
	private JFormattedTextField formattedTextField;
	private JLabel status;
	private CoveragePanel coverageViewer;
	
	/**
	 * Create the dialog.
	 */
	public Window() {
		addWindowListener(new WindowAdapter() {
			@Override
			public void windowClosing(WindowEvent arg0) {
				System.exit(0);
			}
		});
		
		try{
			UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
		} catch(Exception e) {
			System.out.println("UIManager Exception : "+e);
		}
		
		setTitle("Coverage viewer");
		getContentPane().setLayout(new BorderLayout(0, 0));
		
		JPanel panel = new JPanel();
		getContentPane().add(panel, BorderLayout.NORTH);
		panel.setLayout(new BoxLayout(panel, BoxLayout.X_AXIS));
		

		JButton loadButton = new JButton("Load method list");
		loadButton.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent arg0) {
				final JFileChooser fc = new JFileChooser();
				int returnVal = fc.showOpenDialog(Window.this);
				if (returnVal == 0) {
					if (returnVal == JFileChooser.APPROVE_OPTION) {
			            File file = fc.getSelectedFile();
			            try {
							coverageViewer.parseApplicationMethodCsv(file.getAbsolutePath());
						} catch (IOException e) {
							e.printStackTrace();
						}
						status.setText("Opening: " + file.getName() + ".");				
			        } else {
			        	System.out.println("Open command cancelled by user.");
			        }
				}
			}
		});
		panel.add(loadButton);

		Component horizontalStrut = Box.createHorizontalStrut(20);
		panel.add(horizontalStrut);
		
		formattedTextField = new JFormattedTextField();
		formattedTextField.setText("http://10.6.2.29:8182/");
		panel.add(formattedTextField);
		
		JButton resetButton = new JButton("Reset");
		resetButton.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent arg0) {
				String url = formattedTextField.getText();
				if (checkURL(url)) {
					try {
						Client.sendAction(url, "NEWTC");
						status.setText("Reset coverage data.");
					} catch (IOException e) {
						status.setText("Connecion failed! " + e.getMessage());
						e.printStackTrace();
					}
				}
			}
		});
		panel.add(resetButton);
		
		JButton coverageButton = new JButton("Coverage");
		coverageButton.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent arg0) {
				String url = formattedTextField.getText();
				if (checkURL(url)) {
					String result = "";
					try {
						result = Client.sendAction(url, "ASK");
						coverageViewer.updateCoverageInformation(result);
						status.setText("Print coverage data.");				
					} catch (IOException e) {
						status.setText("Connecion failed! " + e.getMessage());
						e.printStackTrace();
					}
				}
			}
		});
		panel.add(coverageButton);
		
		coverageViewer = new CoveragePanel();
		JScrollPane sp = new JScrollPane(coverageViewer);
		getContentPane().add(sp, BorderLayout.CENTER);
		
		JPanel statusBar = new JPanel();
		getContentPane().add(statusBar, BorderLayout.SOUTH);
		statusBar.setLayout(new BorderLayout(0, 0));
		
		JSeparator separator = new JSeparator();
		statusBar.add(separator, BorderLayout.NORTH);
		
		status = new JLabel("");
		statusBar.add(status, BorderLayout.CENTER);
		
		Component horizontalStrut_1 = Box.createHorizontalStrut(10);
		statusBar.add(horizontalStrut_1, BorderLayout.WEST);
		
		Component verticalStrut_1 = Box.createVerticalStrut(15);
		statusBar.add(verticalStrut_1, BorderLayout.EAST);
	}
	
	private boolean checkURL(String url) {
		try {
			new URL(url);
			return true;
		} catch (MalformedURLException e) {
			status.setText("Invalid URL!");
		}
		return false;
	}

}
